--[[
-- MoWater - A simple addon for reminding to you drink when you end combat
-- 		by PProvost <peter@provost.org> aka Quaiche of Dragonblight
--
-- Dedicated to Modag of Dragonblight who always reminded me to drink.
-- 
-- Last Modified: $Date: 2007-09-27 10:31:49 -0700 (Thu, 27 Sep 2007) $
-- Revision: $Revision: 96 $
-- This software is licensed under a zlib/libpng license.  
-- 		See attached License.txt
--
-- TODO:
-- 	* Localize UI strings
-- 	* Add a configuration UI instead of slash commands
--]]

assert(DongleStub, "MoWater requires DongleStub")

local MAJOR_VERSION = "1.0"
local MINOR_VERSION = tonumber((string.gsub("$Revision: 96 $", "^.-(%d+).-$", "%1")))

MoWater = DongleStub("Dongle-1.0"):New("MoWater")
MoWater.version = MAJOR_VERSION .. "." .. MINOR_VERSION
MoWater.date = string.gsub("$Date: 2007-09-27 10:31:49 -0700 (Thu, 27 Sep 2007) $", "^.-(%d%d%d%d%-%d%d%-%d%d).-$", "%1")

function MoWater:Initialize()
	local frame = CreateFrame("Frame")
	local t = 0
	function frame:OnUpdate(elapsed)
		t = t+elapsed
		if t < 1.0 then
			return
		end
		t=0
		MoWater:CheckMana(MoWater)
	end

	frame:SetScript("OnUpdate", frame.OnUpdate)

	self.timerFrame = frame
	self.inCombat = false
end

function MoWater:Enable()
	self.defaults = {
		profile = {
			sound = true,
			threshold = 0.75,
		}
	}

	self.db = self:InitializeDB("MoWaterDB", self.defaults)
	self:RegisterEvent("PLAYER_REGEN_ENABLED")
	self:RegisterEvent("PLAYER_REGEN_DISABLED")

	self.cmd = self:InitializeSlashCommand("MoWater commands", "MoWater", "mowater")
	self.cmd:InjectDBCommands(self.db, "copy", "delete", "list", "reset", "set")
	self.cmd:RegisterSlashHandler("limit <num> - Set mana threshold percent", "^limit%s*(%d*)$", "SetThreshold")
	self.cmd:RegisterSlashHandler("sound y|n - Turns sound file on or off", "^sound%s+([yn]?)$", "ToggleSound")

	self.timerFrame:Show()
end

function MoWater:Disable()
	self.timerFrame:Hide()
end

function MoWater:SetThreshold(threshold)
	threshold = tonumber(threshold)
	if threshold and threshold >=0 and threshold <= 100 then
		self.db.profile.threshold = threshold/100
		self:PrintF("Limit set to %d", threshold)
	else
		self:PrintF("Current limit is %d", self.db.profile.threshold*100)
		self:Print("Limit must be a number between 0 and 100")
	end
end

function MoWater:ToggleSound(val)
	if val then
		self.db.profile.sound = (val == "y")
		self:PrintF("Sound has been %s.", self.db.profile.sound and "enabled" or "disabled")
	else
		self:PrintF("Sound is %s.", self.sb.profile.sound and "enabled" or "disabled")
	end
end

function MoWater:PLAYER_REGEN_DISABLED()
	self.inCombat = true
end

function MoWater:PLAYER_REGEN_ENABLED()
	self.inCombat = false
end

function MoWater:NeedsWater()
	local pct = UnitMana("player") / UnitManaMax("player")
	return (pct <= self.db.profile.threshold) 
			and (not UnitIsDeadOrGhost("player"))
			and (UnitPowerType("player") ~= 1)
			and (UnitPowerType("player") ~= 2)
			and (not self.inCombat)
end

function MoWater:CheckMana()
	if self:NeedsWater()	then
			self:DisplayMessage("DRINK!", "Interface\\Addons\\MoWater\\Drink.wav")
	end
end

function MoWater:DisplayMessage(message, sound)
	local t = GetTime()
	if not self.LastMessageTime then
		self.LastMessageTime = 0
	end

	if self.LastMessageTime + 10 <= t then
		if SCT then
			SCT:DisplayMessage(message, {r = 1.0, g = 1.0, b = 0.0})
		else
			UIErrorsFrame:AddMessage(message, 1.0, 1.0, 0.0, 5)
		end	
		
		if self.db.profile.sound and sound then
			PlaySoundFile(sound);
		end
		
		self.LastMessageTime = t
	end	
end


